pymchelper
==========

**pymchelper** is a toolkit for manipulating output and input files of particle transport codes,
such as FLUKA and SHIELD-HIT12A.
It provides a command line program, called **convertmc** which simplifies process of converting binary output
files to graphs, tabulated plain data files (which can be open by MS Excel) and other formats.
Toolkit can also serve as a library in Python language, which can be used by programmers and data scientists 
to read data from binary files into convenient Python objects. 
This allows further data processing using other Python tools and libraries.

**pymchelper** works under Linux, Windows and Mac OSX operating systems
(interpreter of Python programming language has to be also installed).
No programming knowledge is required from user, but basic skills in working with terminal console are needed.


Documentation
-------------

Full PyTRiP documentation can be found here: https://pymchelper.readthedocs.io/

See `Getting Started <https://pymchelper.readthedocs.org/en/stable/getting_started.html>`_ for installation and basic
information, and the `User's Guide <https://pymchelper.readthedocs.org/en/stable/user_guide.html>`_ for an overview of
how to use the project.